@@ -1,6 +1,6 @@
 package Method::Signatures::Simple;
-BEGIN {
-  $Method::Signatures::Simple::VERSION = '1.02';
+{
+  $Method::Signatures::Simple::VERSION = '1.05';
 }
 
 use warnings;
@@ -12,11 +12,11 @@ Method::Signatures::Simple - Basic method declarations with signatures, without
 
 =head1 VERSION
 
-version 1.02
+version 1.05
 
 =cut
 
-use base q/Devel::Declare::MethodInstaller::Simple/;
+use base 'Devel::Declare::MethodInstaller::Simple';
 
 sub import {
     my $class = shift;
@@ -49,14 +49,39 @@ sub import {
     }
 }
 
+sub strip_proto {
+    my $self = shift;
+    my ($proto) = $self->SUPER::strip_proto()
+      or return '';
+    # we strip comments and newlines here, and stash the number of newlines.
+    # we will re-inject the newlines in strip_attrs(), because DD does not
+    # like it when you inject them into the following code block. it does not
+    # object to tacking on newlines to the code attribute spec though.
+    # (see the call to inject_if_block() in DD::MethodInstaller::Simple->parser)
+    $proto =~ s/\s*#.*$//mg;
+    $self->{__nls} = $proto =~ s/[\r\n]//g;
+    $proto;
+}
+
+sub strip_attrs {
+    my $self = shift;
+    my ($attrs) = $self->SUPER::strip_attrs();
+    $attrs ||= '';
+    $attrs .= $/ x $self->{__nls} if $self->{__nls};
+    $attrs;
+}
+
 sub parse_proto {
     my $self = shift;
     my ($proto) = @_;
     $proto ||= '';
+    $proto =~ s/\s*#.*$//mg;
+    $proto =~ s/^\s+//mg;
+    $proto =~ s/\s+$//mg;
     $proto =~ s/[\r\n]//g;
     my $invocant = $self->{invocant};
 
-    $invocant = $1 if $proto =~ s{^(\$\w+):\s*}{};
+    $invocant = $1 if $proto =~ s{(\$\w+)\s*:\s*}{};
 
     my $inject = '';
     $inject .= "my ${invocant} = shift;" if $invocant;
